@@ -12,6 +12,33 @@ classifiers = {
     "Environment :: Console :: Framebuffer",
     "Environment :: Console :: Newt",
     "Environment :: Console :: svgalib",
+    "Environment :: GPU",
+    "Environment :: GPU :: NVIDIA CUDA",
+    "Environment :: GPU :: NVIDIA CUDA :: 1.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 1.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 2.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 2.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 2.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 2.3",
+    "Environment :: GPU :: NVIDIA CUDA :: 3.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 3.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 3.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 4.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 4.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 4.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 5.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 5.5",
+    "Environment :: GPU :: NVIDIA CUDA :: 6.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 6.5",
+    "Environment :: GPU :: NVIDIA CUDA :: 7.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 7.5",
+    "Environment :: GPU :: NVIDIA CUDA :: 8.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 9.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 9.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 9.2",
+    "Environment :: GPU :: NVIDIA CUDA :: 10.0",
+    "Environment :: GPU :: NVIDIA CUDA :: 10.1",
+    "Environment :: GPU :: NVIDIA CUDA :: 10.2",
     "Environment :: Handhelds/PDA's",
     "Environment :: MacOS X",
     "Environment :: MacOS X :: Aqua",
@@ -59,6 +86,7 @@ classifiers = {
     "Framework :: Django :: 2.1",
     "Framework :: Django :: 2.2",
     "Framework :: Django :: 3.0",
+    "Framework :: Django :: 3.1",
     "Framework :: Django CMS",
     "Framework :: Django CMS :: 3.4",
     "Framework :: Django CMS :: 3.5",
